@@ -1,5 +1,6 @@
 #
-# Copyright 2020 Lars Pastewka
+# Copyright 2021-2022 Johannes Laurin Hörmann
+#           2020-2021 Lars Pastewka
 #
 # ### MIT license
 #
@@ -23,5 +24,5 @@
 #
 
 if __name__ == '__main__':
-    from .MainApplication import run_gui
-    run_gui()
\ No newline at end of file
+    from .main import run_gui
+    run_gui()
