@@ -1,6 +1,6 @@
 #
-# Copyright 2020-2021 Lars Pastewka
-#           2021 Johannes Hörmann
+# Copyright 2021-2022 Johannes Laurin Hörmann
+#           2020-2021 Lars Pastewka
 #
 # ### MIT license
 #
@@ -37,6 +37,7 @@ from dtool_info.utils import date_fmt, sizeof_fmt
 from dtool_info.inventory import _dataset_info
 from dtool_lookup_api.core.LookupClient import ConfigurationBasedLookupClient
 
+from ..utils.logging import _log_nested
 from ..utils.multiprocessing import StatusReportingChildProcessBuilder, process_initializer
 from ..utils.progressbar import ProgressBar
 
@@ -79,8 +80,11 @@ def _proto_dataset_info(dataset):
 
     try:
         info['readme_content'] = dataset.get_readme_content()
-    except FileNotFoundError as exc:
-        logger.warning(str(exc))
+    except Exception as exc:  # exception here depends on storage broker
+        # i.e. FileNotFoundError on local file system, or
+        # botocore.errorfactory.NoSuchKey: An error occurred (NoSuchKey) when calling the GetObject operation: The specified key does not exist.
+        # on dtool-s3
+        logger.warning(f"{dataset.uuid}, {dataset.uri}: {str(exc)}")
         info['readme_content'] = ''
 
 
@@ -212,7 +216,7 @@ async def _copy_dataset(uri, target_base_uri, resume, auto_resume, progressbar=N
 
     copy_func_wrapper = CopyFuncWrapper(copy_func)
 
-    with ProgressBar(length=num_items,
+    with ProgressBar(length=2*num_items,
                      label="Copying dataset",
                      pb=progressbar) as pb:
         non_blocking_copy_func = StatusReportingChildProcessBuilder(copy_func_wrapper, pb)
@@ -331,10 +335,13 @@ class DatasetModel:
 
     async def get_readme(self):
         if 'readme_content' in self._dataset_info:
+            logger.debug("README.yml cached.")
             return self._dataset_info['readme_content']
+
+        logger.debug("README.yml queried from lookup server.")
         async with ConfigurationBasedLookupClient() as lookup:
             readme_dict = await lookup.readme(self.uri)
-        self._dataset_info['readme_content'] = yaml.dump(readme_dict)
+        self._dataset_info['readme_content'] = yaml.dump(readme_dict, allow_unicode=True)
         return self._dataset_info['readme_content']
 
     async def get_manifest(self):
@@ -359,4 +366,4 @@ class DatasetModel:
             logger.debug(f"Retrieved cached item {cached_file}.")
             return cached_file
         else:
-            raise ValueError(f"Item UUID '{item_uuid}' does not exist within dataset '{str(self)}'.")
\ No newline at end of file
+            raise ValueError(f"Item UUID '{item_uuid}' does not exist within dataset '{str(self)}'.")
