@@ -23,18 +23,31 @@
 # SOFTWARE.
 #
 
+import logging
 import os
 
 from gi.repository import Gio
 
 
+logger = logging.getLogger(__name__)
+
+
 class Settings:
     def __init__(self):
         schema_source = Gio.SettingsSchemaSource.new_from_directory(
             os.path.abspath(f'{os.path.dirname(__file__)}/..'), Gio.SettingsSchemaSource.get_default(), False)
-        schema = Gio.SettingsSchemaSource.lookup(
+        self._schema = Gio.SettingsSchemaSource.lookup(
             schema_source, "de.uni-freiburg.dtool-lookup-gui", False)
-        self.settings = Gio.Settings.new_full(schema, None, None)
+        self.settings = Gio.Settings.new_full(self._schema, None, None)
+
+    def reset(self):
+        """Reset Gtk app settings to defaults."""
+        keys = self._schema.list_keys()
+        for key in keys:
+            value = self.settings.get_value(key)
+            self.settings.reset(key)
+            default = self.settings.get_value(key)
+            logger.debug("Reset '%s': '%s' back to default '%s'", key, value, default)
 
     @property
     def dependency_keys(self):
@@ -48,4 +61,29 @@ class Settings:
     def local_base_uris(self, value):
         self.settings.set_strv('local-base-uris', value)
 
+    @property
+    def item_download_directory(self):
+        return self.settings.get_string('item-download-directory')
+
+    @item_download_directory.setter
+    def item_download_directory(self, value):
+        self.settings.set_string('item-download-directory', value)
+
+    @property
+    def choose_item_download_directory(self):
+        return self.settings.get_boolean('choose-item-download-directory')
+
+    @choose_item_download_directory.setter
+    def choose_item_download_directory(self, value):
+        self.settings.set_boolean('choose-item-download-directory', value)
+
+    @property
+    def open_downloaded_item(self):
+        return self.settings.get_boolean('open-downloaded-item')
+
+    @open_downloaded_item.setter
+    def open_downloaded_item(self, value):
+        self.settings.set_boolean('open-downloaded-item', value)
+
+
 settings = Settings()
